#[non_exhaustive]pub struct FileProgress {
pub bytes_written: u64,
pub content_length: Option<u64>,
}Expand description
A progress report from a body write in flight.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.bytes_written: u64Bytes written to the file so far.
content_length: Option<u64>The Content-Length the response advertised. Absent for a chunked response, and for one
being decoded, where the final size is not known ahead of time.