#[non_exhaustive]pub struct FileWritten {
pub path: PathBuf,
pub bytes_written: u64,
}Expand description
The result of writing a body to a file.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.path: PathBufThe absolute filesystem path written to.
bytes_written: u64The number of bytes that landed at the destination.